@@ -3,5 +3,5 @@
 # * 0.3     - released version
 # * 0.3a1   - alpha version
 # * 0.3.dev - version in development
-__version__ = '0.1.2'
-__releasedate__ = ''
+__version__ = '1.0'
+__releasedate__ = '30-10-2013'
